@@ -125,6 +125,8 @@ class BaseNetworkTest(test.BaseTestCase):
         cls.qos_rules = []
         cls.qos_policies = []
         cls.ethertype = "IPv" + str(cls._ip_version)
+        cls.address_groups = []
+        cls.admin_address_groups = []
         cls.address_scopes = []
         cls.admin_address_scopes = []
         cls.subnetpools = []
@@ -139,6 +141,17 @@ class BaseNetworkTest(test.BaseTestCase):
         cls.network_segment_ranges = []
         cls.conntrack_helpers = []
 
+    @classmethod
+    def reserve_external_subnet_cidrs(cls):
+        client = cls.os_admin.network_client
+        ext_nets = client.list_networks(
+            **{"router:external": True})['networks']
+        for ext_net in ext_nets:
+            ext_subnets = client.list_subnets(
+                network_id=ext_net['id'])['subnets']
+            for ext_subnet in ext_subnets:
+                cls.reserve_subnet_cidr(ext_subnet['cidr'])
+
     @classmethod
     def resource_cleanup(cls):
         if CONF.service_available.neutron:
@@ -701,6 +714,12 @@ class BaseNetworkTest(test.BaseTestCase):
         cls.port_forwardings.append(pf)
         return pf
 
+    @classmethod
+    def update_port_forwarding(cls, fip_id, pf_id, client=None, **kwargs):
+        """Wrapper utility for update_port_forwarding."""
+        client = client or cls.client
+        return client.update_port_forwarding(fip_id, pf_id, **kwargs)
+
     @classmethod
     def delete_port_forwarding(cls, pf, client=None):
         """Delete port forwarding
@@ -803,6 +822,16 @@ class BaseNetworkTest(test.BaseTestCase):
             cls.subnetpools.append(body['subnetpool'])
         return body['subnetpool']
 
+    @classmethod
+    def create_address_group(cls, name, is_admin=False, **kwargs):
+        if is_admin:
+            body = cls.admin_client.create_address_group(name=name, **kwargs)
+            cls.admin_address_groups.append(body['address_group'])
+        else:
+            body = cls.client.create_address_group(name=name, **kwargs)
+            cls.address_groups.append(body['address_group'])
+        return body['address_group']
+
     @classmethod
     def create_project(cls, name=None, description=None):
         test_project = name or data_utils.rand_name('test_project_')
@@ -869,6 +898,9 @@ class BaseNetworkTest(test.BaseTestCase):
         ip_version = ip_version or cls._ip_version
         default_params = (
             constants.DEFAULT_SECURITY_GROUP_RULE_PARAMS[ip_version])
+        if ('remote_address_group_id' in kwargs and 'remote_ip_prefix' in
+                default_params):
+            default_params.pop('remote_ip_prefix')
         for key, value in default_params.items():
             kwargs.setdefault(key, value)
 
